@@ -1,16 +1,16 @@
-# $Id: Parse.pm,v 2.3 2002/03/16 14:09:27 eserte Exp $
+# $Id: Parse.pm 1.7 Mon, 05 Oct 1998 20:12:57 +0200 ach $
 
 package Tk::Parse;
 
 require Exporter;
 
 use vars qw($VERSION %Escapes);
-$VERSION = substr(q$Revision: 2.3 $, 10) + 1 . "";
+$VERSION = substr(q$Revision: 1.7 $, 10) + 1; # bigger than 2.004 before :-)
 
 @ISA=qw(Exporter);
 @EXPORT=qw(Parse Simplify hide start_hide unhide Normalize Normalize2 Escapes
 	$VERBATIM $HEADING $ITEM $INDEX $TEXT $PRAGMA $INDENT );
-
+	
 # Different types of text:
 
 # 0. Name of file
@@ -37,11 +37,11 @@ $VERSION = substr(q$Revision: 2.3 $, 10) + 1 . "";
 
 =head1 NAME
 
-Tk::Parse - Parse perl's pod files (code deprecated. Use Pod::Parser instead).
+Pod::Parse - Parse perl's pod files.
 
 =head1 SYNOPSIS
 
-B<THIS TK SNAPSHOT SHOULD BE REPLACED BY CPAN MODULE:> L<Pod::Parser>
+B<THIS TK SNAPSHOT SHOULD BE REPLACED BY A CPAN MODULE>
 
 =head1 DESCRIPTION
 
@@ -66,9 +66,9 @@ like this:
   foo2
   foo3
   foo2!subfoo
-
+  
   Foo!
-
+ 
 Will become:
 
   X<foo>X<foo2>X<foo3>X<foo2!subfoo>Foo!
@@ -84,14 +84,14 @@ Inside an =command, no special significance is to be placed on the first line
 of the argument. Thus the following two lines should be parsed identically:
 
  =item 1. ABC
-
+ 
  =item 1.
  ABC
 
 Note that neither of these are identical to this:
 
  =item 1.
-
+ 
  ABC
 
 which puts the "ABC" in a separate paragraph.
@@ -204,46 +204,46 @@ three types: enumeration, itemization, or description. To exemplify:
 An itemized list
 
   =over 4
-
+  
   =item *
-
+  
   A bulleted item
-
+  
   =item *
-
+  
   Another bulleted item
-
+ 
   =back
-
+  
 An enumerated list
 
   =over 4
-
+  
   =item 1.
-
+  
   First item.
-
+  
   =item 2.
-
+  
   Second item.
-
+  
   =back
-
+  
 A described list
 
   =over 4
-
+  
   =item Item #1
-
+  
   First item
-
+  
   =item Item #2 (which isn't really like #1, but is the second).
-
+  
   Second item
-
-  =back
-
-
+  
+  =back  
+  
+  
 If you aren't consistent about the arguments to =item, Pod::Parse will
 complain.
 
@@ -315,7 +315,7 @@ End of same.
 
 =item [1,$line,$pos,0,$verbatim]
 
-This is produced for each paragraph of verbatim text. $verbatim is the text,
+This is produced for each paragraph of verbatim text. $verbatim is the text, 
 $line is the line offset of the paragraph within the file, and $pos is the
 byte offset. (In all of the following elements, $pos and $line have identical
 meanings, so I'll skip explaining them each time.)
@@ -370,7 +370,7 @@ designed to be easy (easier?) to parse in your pod formatting code.
 It is used very simply by saying something like:
 
  @Pod = Simplify(Parse());
-
+ 
  while($cmd = shift @Pod) { $arg = shift @Pod;
  	#...
  }
@@ -484,7 +484,7 @@ for your benefit. Consider the following example:
  listend 2
  back 0
  listtype 0
-
+ 
 =head2 Normalize
 
 This command is normally invoked by Parse, so you shouldn't need to deal
@@ -503,17 +503,6 @@ This hash is exported from Pod::Parse, and contains default ASCII
 translations for some common HTML escape sequences. You might like to use this
 as a basis for an %HTML_Escapes array in your own formatter.
 
-=head1 AUTHOR
-
-Brad Appleton <F<bradapp@enteract.com>>
-
-Code currently maintained (but deprecated) by Slaven Rezic
-<F<slaven.rezic@berlin.de>>. Use L<Pod::Parser> instead.
-
-Copyright (c) 1997-1998 Brad Appleton.  All rights reserved.  This program
-is free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.
-
 =cut
 
 $ENDFILE = -1;
@@ -527,7 +516,7 @@ $PRAGMA = 7;
 $INDENT = 8;
 $CUT = 9;
 
-
+	   
 
 
 
@@ -538,19 +527,19 @@ sub hide {
     $thing_to_hide =~ tr/\000-\177/\200-\377/;
     return $thing_to_hide;
 }
-
+            
 sub start_hide {
     if ( /[\200-\377]/ ) {
         warn "hit bit char in input stream";
     }
 }
-
+                            
 sub unhide {
     local($tmp) = shift;
     $tmp =~ tr/\200-\377/\000-\177/;
     return $tmp;
 }
-
+                                        
 
 # Turn formatted text into a more normalized version. All '<' and '>' will
 # belong to a command, the rest will have turned into E<lt> and E<gt>. '&'
@@ -562,7 +551,7 @@ sub Normalize {
 	start_hide;
         s/(E<[^<>]*>)/hide($1)/ge;
         s/([A-Z]<[^<>]*>)/hide($1)/ge;
-
+        
         s/</hide("E<lt>")/ge;
         s/>/hide("E<gt>")/ge;
         s/&/hide("E<amp>")/ge;
@@ -572,26 +561,26 @@ sub Normalize {
         #	{
         #	warn "``$1'' should be a [LCI]<$1> ref near line $line of $ARGV\n";
         #}
-
+        
         while (/(-[a-zA-Z])\b/g && $` !~ /[\w\-]$/) {
 		warn  "``$1'' should be [CB]<$1> ref near line $line of $ARGV\n";
 	}
-
+        
 	# put back pod quotes so we get the inside of <> processed;
         $_ = unhide($_);
-
+        
 }
 
 # Apply heuristics to a formatted string.
 sub Normalize2 {
-	local($_) = @_;
-
+	local($_) = @_;        
+        
 	# func() is a reference to a perl function
        	s{\b([:\w]+\(\))}{I<$1>}g;
-       
+       	
         # func(n) is a reference to a man page
         s{(\w+)(\([^\s,\051]+\))}{I<$1>$2}g;
-
+        
         # convert simple variable references
         s/(\s+)([\$\@%][\w:]+)/${1}C<$2>/g;
         #       s/([\$\@%][\w:]+)/C<$1>/g;
@@ -601,7 +590,7 @@ sub Normalize2 {
 
 # Take output from the following Parse routine, and turns it into a much
 # more straightforward, non-recursive, data structure. It returns an
-# array consisting of pairs of elements, the first of each pair being a
+# array consisting of pairs of elements, the first of each pair being a 
 # command, and the second it's argument. Hopefully this should prove
 # simple to parse. Note that it is intended that your formatter only "listens"
 # for the commands it is interested in, and simply discards the rest.
@@ -656,8 +645,8 @@ sub Simplify2 {
 sub Parse {
 	local(@ARGV)=@ARGV;
 	if(@_) { @ARGV = @_ }
-
-	local($/) = "";
+	
+	local($/);
 
 	$type=0;
 	$typecount=0;
@@ -665,6 +654,8 @@ sub Parse {
 	$bof=1;
 	$saveindex="";
 
+	$/="";
+	
 	$cutting=1;
 
 	$recurse=0;
@@ -674,10 +665,10 @@ sub Parse {
 	$loc=0;
 
 	$newloc=0; $newline=0;
-
+	
 	$infile = undef;
 
-
+	
 	&Parse2();
 
 }
@@ -700,12 +691,12 @@ sub Parse2 {
 		$line=$newline;
 		$newloc = $loc + length($_);
 		$newline= $line + (tr/\n/\n/);
-
+		
 		#Should I?
 		#s/[ \t]+$//gm;
-
+		
 		#print STDERR "Read $_\n";
-
+		
 		if($saw_begin) {
 			if (/^=end/) {
 				$saw_begin=0;
@@ -719,19 +710,19 @@ sub Parse2 {
 		}
 		$cutting=0;
 		chomp;
-
+		
 		if(/^=cut/) {
 			$cutting=1;
 			push(@result,[9,$line,$loc,0,0]);
 			next;
 		}
-
+	
 		if(/^=begin/) {
 			$cutting=1;
 			$saw_begin=1;
 			next;
 		}
-
+	
 		if(/^\s/) {
 			push(@result,[1,$line,$loc,0,$_]);
 		} elsif( /^=head(\d+)\s*/ ) {
@@ -762,7 +753,7 @@ sub Parse2 {
 					warn "Inconsistently numbered =item near line $line of $ARGV\n";
 					$typecount = $1;
 				}
-
+				
 			} else {
 				if( $type == 0 || $type == 3) {
 					$type = 3;
@@ -771,7 +762,7 @@ sub Parse2 {
 				}
 			}
 			push(@result,[3,$line,$loc,0,Normalize($data)]);
-
+			
 		} elsif( /^=over(?:\s+(\d+))?/ ) {
 			my($indent,$l1,$l2)=($1,$line,$loc);
 			$indent ||= 5; # good?
@@ -787,7 +778,7 @@ sub Parse2 {
 		} elsif( /^=back/ ) {
 			if(!$recurse) {
 				die "Unmatched =back near line $line of $ARGV\n";
-			}
+			} 
 			return @result;
 		} elsif( /^=pragma\s*/) {
 			push(@result,[7,$line,$loc,0,$']);
@@ -812,7 +803,7 @@ sub Parse2 {
 			}
 			push(@result,[6,$line,$loc,0,Normalize($_)]);
 		}
-
+		
 	}
 	$eof=1;
 	if($recurse) {
@@ -832,124 +823,75 @@ sub Parse2 {
 # Common escapes with ASCII translations. You should copy this into you're
 # own local escapes hash and override the ones you need to change.
 
-if (eval { require Pod::Text &&
-	   Pod::Text->VERSION(2) &&
-           defined %Pod::Text::ESCAPES
-    }) {
-    %Escapes = %Pod::Text::ESCAPES;
-} else {
-    # fallback...
 %Escapes = (
-    'amp'       =>    '&',      # ampersand
-    'apos'      =>    "'",      # apostrophe
-    'lt'        =>    '<',      # left chevron, less-than
-    'gt'        =>    '>',      # right chevron, greater-than
-    'quot'      =>    '"',      # double quote
-    'sol'       =>    '/',      # solidus (forward slash)
-    'verbar'    =>    '|',      # vertical bar
+    'amp'	=>	'&',	#   ampersand
+    'lt'	=>	'<',	#   left chevron, less-than
+    'gt'	=>	'>',	#   right chevron, greater-than
+    'quot'	=>	'"',	#   double quote
 
-    "Aacute"    =>    "\xC1",   # capital A, acute accent
-    "aacute"    =>    "\xE1",   # small a, acute accent
-    "Acirc"     =>    "\xC2",   # capital A, circumflex accent
-    "acirc"     =>    "\xE2",   # small a, circumflex accent
-    "AElig"     =>    "\xC6",   # capital AE diphthong (ligature)
-    "aelig"     =>    "\xE6",   # small ae diphthong (ligature)
-    "Agrave"    =>    "\xC0",   # capital A, grave accent
-    "agrave"    =>    "\xE0",   # small a, grave accent
-    "Aring"     =>    "\xC5",   # capital A, ring
-    "aring"     =>    "\xE5",   # small a, ring
-    "Atilde"    =>    "\xC3",   # capital A, tilde
-    "atilde"    =>    "\xE3",   # small a, tilde
-    "Auml"      =>    "\xC4",   # capital A, dieresis or umlaut mark
-    "auml"      =>    "\xE4",   # small a, dieresis or umlaut mark
-    "Ccedil"    =>    "\xC7",   # capital C, cedilla
-    "ccedil"    =>    "\xE7",   # small c, cedilla
-    "Eacute"    =>    "\xC9",   # capital E, acute accent
-    "eacute"    =>    "\xE9",   # small e, acute accent
-    "Ecirc"     =>    "\xCA",   # capital E, circumflex accent
-    "ecirc"     =>    "\xEA",   # small e, circumflex accent
-    "Egrave"    =>    "\xC8",   # capital E, grave accent
-    "egrave"    =>    "\xE8",   # small e, grave accent
-    "ETH"       =>    "\xD0",   # capital Eth, Icelandic
-    "eth"       =>    "\xF0",   # small eth, Icelandic
-    "Euml"      =>    "\xCB",   # capital E, dieresis or umlaut mark
-    "euml"      =>    "\xEB",   # small e, dieresis or umlaut mark
-    "Iacute"    =>    "\xCD",   # capital I, acute accent
-    "iacute"    =>    "\xED",   # small i, acute accent
-    "Icirc"     =>    "\xCE",   # capital I, circumflex accent
-    "icirc"     =>    "\xEE",   # small i, circumflex accent
-    "Igrave"    =>    "\xCC",   # capital I, grave accent
-    "igrave"    =>    "\xEC",   # small i, grave accent
-    "Iuml"      =>    "\xCF",   # capital I, dieresis or umlaut mark
-    "iuml"      =>    "\xEF",   # small i, dieresis or umlaut mark
-    "Ntilde"    =>    "\xD1",   # capital N, tilde
-    "ntilde"    =>    "\xF1",   # small n, tilde
-    "Oacute"    =>    "\xD3",   # capital O, acute accent
-    "oacute"    =>    "\xF3",   # small o, acute accent
-    "Ocirc"     =>    "\xD4",   # capital O, circumflex accent
-    "ocirc"     =>    "\xF4",   # small o, circumflex accent
-    "Ograve"    =>    "\xD2",   # capital O, grave accent
-    "ograve"    =>    "\xF2",   # small o, grave accent
-    "Oslash"    =>    "\xD8",   # capital O, slash
-    "oslash"    =>    "\xF8",   # small o, slash
-    "Otilde"    =>    "\xD5",   # capital O, tilde
-    "otilde"    =>    "\xF5",   # small o, tilde
-    "Ouml"      =>    "\xD6",   # capital O, dieresis or umlaut mark
-    "ouml"      =>    "\xF6",   # small o, dieresis or umlaut mark
-    "szlig"     =>    "\xDF",   # small sharp s, German (sz ligature)
-    "THORN"     =>    "\xDE",   # capital THORN, Icelandic
-    "thorn"     =>    "\xFE",   # small thorn, Icelandic
-    "Uacute"    =>    "\xDA",   # capital U, acute accent
-    "uacute"    =>    "\xFA",   # small u, acute accent
-    "Ucirc"     =>    "\xDB",   # capital U, circumflex accent
-    "ucirc"     =>    "\xFB",   # small u, circumflex accent
-    "Ugrave"    =>    "\xD9",   # capital U, grave accent
-    "ugrave"    =>    "\xF9",   # small u, grave accent
-    "Uuml"      =>    "\xDC",   # capital U, dieresis or umlaut mark
-    "uuml"      =>    "\xFC",   # small u, dieresis or umlaut mark
-    "Yacute"    =>    "\xDD",   # capital Y, acute accent
-    "yacute"    =>    "\xFD",   # small y, acute accent
-    "yuml"      =>    "\xFF",   # small y, dieresis or umlaut mark
-
-    "laquo"     =>    "\xAB",   # left pointing double angle quotation mark
-    "lchevron"  =>    "\xAB",   #  synonym (backwards compatibility)
-    "raquo"     =>    "\xBB",   # right pointing double angle quotation mark
-    "rchevron"  =>    "\xBB",   #  synonym (backwards compatibility)
-
-    "iexcl"     =>    "\xA1",   # inverted exclamation mark
-    "cent"      =>    "\xA2",   # cent sign
-    "pound"     =>    "\xA3",   # (UK) pound sign
-    "curren"    =>    "\xA4",   # currency sign
-    "yen"       =>    "\xA5",   # yen sign
-    "brvbar"    =>    "\xA6",   # broken vertical bar
-    "sect"      =>    "\xA7",   # section sign
-    "uml"       =>    "\xA8",   # diaresis
-    "copy"      =>    "\xA9",   # Copyright symbol
-    "ordf"      =>    "\xAA",   # feminine ordinal indicator
-    "not"       =>    "\xAC",   # not sign
-    "shy"       =>    '',       # soft (discretionary) hyphen
-    "reg"       =>    "\xAE",   # registered trademark
-    "macr"      =>    "\xAF",   # macron, overline
-    "deg"       =>    "\xB0",   # degree sign
-    "plusmn"    =>    "\xB1",   # plus-minus sign
-    "sup2"      =>    "\xB2",   # superscript 2
-    "sup3"      =>    "\xB3",   # superscript 3
-    "acute"     =>    "\xB4",   # acute accent
-    "micro"     =>    "\xB5",   # micro sign
-    "para"      =>    "\xB6",   # pilcrow sign = paragraph sign
-    "middot"    =>    "\xB7",   # middle dot = Georgian comma
-    "cedil"     =>    "\xB8",   # cedilla
-    "sup1"      =>    "\xB9",   # superscript 1
-    "ordm"      =>    "\xBA",   # masculine ordinal indicator
-    "frac14"    =>    "\xBC",   # vulgar fraction one quarter
-    "frac12"    =>    "\xBD",   # vulgar fraction one half
-    "frac34"    =>    "\xBE",   # vulgar fraction three quarters
-    "iquest"    =>    "\xBF",   # inverted question mark
-    "times"     =>    "\xD7",   # multiplication sign
-    "divide"    =>    "\xF7",   # division sign
-
-    "nbsp"      =>    "\xA0",   # non-breaking space # XXX differs!
+    "Aacute"	=>	"A",	#   capital A, acute accent
+    "aacute"	=>	"a",	#   small a, acute accent
+    "Acirc"	=>	"A",	#   capital A, circumflex accent
+    "acirc"	=>	"a",	#   small a, circumflex accent
+    "AElig"	=>	'Ae',		#   capital AE diphthong (ligature)
+    "aelig"	=>	'ae',		#   small ae diphthong (ligature)
+    "Agrave"	=>	"A",	#   capital A, grave accent
+    "agrave"	=>	"a",	#   small a, grave accent
+    "Aring"	=>	'A',	#   capital A, ring
+    "aring"	=>	'a',	#   small a, ring
+    "Atilde"	=>	'A',	#   capital A, tilde
+    "atilde"	=>	'a',	#   small a, tilde
+    "Auml"	=>	'A',	#   capital A, dieresis or umlaut mark
+    "auml"	=>	'a',	#   small a, dieresis or umlaut mark
+    "Ccedil"	=>	'C',	#   capital C, cedilla
+    "ccedil"	=>	'c',	#   small c, cedilla
+    "Eacute"	=>	"E",	#   capital E, acute accent
+    "eacute"	=>	"e",	#   small e, acute accent
+    "Ecirc"	=>	"E",	#   capital E, circumflex accent
+    "ecirc"	=>	"e",	#   small e, circumflex accent
+    "Egrave"	=>	"E",	#   capital E, grave accent
+    "egrave"	=>	"e",	#   small e, grave accent
+    "ETH"	=>	'Oe',		#   capital Eth, Icelandic
+    "eth"	=>	'oe',		#   small eth, Icelandic
+    "Euml"	=>	'E',	#   capital E, dieresis or umlaut mark
+    "euml"	=>	'e',	#   small e, dieresis or umlaut mark
+    "Iacute"	=>	"I",	#   capital I, acute accent
+    "iacute"	=>	"i",	#   small i, acute accent
+    "Icirc"	=>	"I",	#   capital I, circumflex accent
+    "icirc"	=>	"i",	#   small i, circumflex accent
+    "Igrave"	=>	"I",	#   capital I, grave accent
+    "igrave"	=>	"i",	#   small i, grave accent
+    "Iuml"	=>	'I',	#   capital I, dieresis or umlaut mark
+    "iuml"	=>	'i',	#   small i, dieresis or umlaut mark
+    "Ntilde"	=>	'N',	#   capital N, tilde
+    "ntilde"	=>	'n',	#   small n, tilde
+    "Oacute"	=>	"O",	#   capital O, acute accent
+    "oacute"	=>	"o",	#   small o, acute accent
+    "Ocirc"	=>	"O",	#   capital O, circumflex accent
+    "ocirc"	=>	"o",	#   small o, circumflex accent
+    "Ograve"	=>	"O",	#   capital O, grave accent
+    "ograve"	=>	"o",	#   small o, grave accent
+    "Oslash"	=>	"O",		#   capital O, slash
+    "oslash"	=>	"o",		#   small o, slash
+    "Otilde"	=>	"O",	#   capital O, tilde
+    "otilde"	=>	"o",	#   small o, tilde
+    "Ouml"	=>	'O',	#   capital O, dieresis or umlaut mark
+    "ouml"	=>	'o',	#   small o, dieresis or umlaut mark
+    "szlig"	=>	'ss',		#   small sharp s, German (sz ligature)
+    "THORN"	=>	'L',		#   capital THORN, Icelandic
+    "thorn"	=>	'l',		#   small thorn, Icelandic
+    "Uacute"	=>	"U",	#   capital U, acute accent
+    "uacute"	=>	"u",	#   small u, acute accent
+    "Ucirc"	=>	"U",	#   capital U, circumflex accent
+    "ucirc"	=>	"u",	#   small u, circumflex accent
+    "Ugrave"	=>	"U",	#   capital U, grave accent
+    "ugrave"	=>	"u",	#   small u, grave accent
+    "Uuml"	=>	'U',	#   capital U, dieresis or umlaut mark
+    "uuml"	=>	'u',	#   small u, dieresis or umlaut mark
+    "Yacute"	=>	"Y",	#   capital Y, acute accent
+    "yacute"	=>	"y",	#   small y, acute accent
+    "yuml"	=>	'y',	#   small y, dieresis or umlaut mark
 );
-}
+
 
 1;
